@@ -38,6 +38,7 @@
 #include <string.h>
 #include <errno.h>
 #include <sys/stat.h>
+#include <stdint.h>
 
 #define PLUGIN_NAME	"DiskPerf"
 #define BORDER          8
@@ -79,7 +80,7 @@ typedef enum monitor_bar_order_t {
 
 typedef struct param_t {
     /* Configurable parameters */
-    char            acDevice[64];
+    char            acDevice[128];
 #if  !defined(__FreeBSD__) && !defined(__NetBSD__) && !defined(__OpenBSD__) && !defined(__sun__)
     dev_t           st_rdev;
 #endif
@@ -480,16 +481,16 @@ static diskperf_t *diskperf_create_control (XfcePanelPlugin *plugin)
     poPlugin->plugin = plugin;
     
 #if defined(__NetBSD__) || defined(__OpenBSD__)
-    strncpy (poConf->acDevice, "wd0", 64);
+    strncpy (poConf->acDevice, "wd0", 128);
     strncpy (poConf->acTitle, "wd0", 16);
 #elif defined(__FreeBSD__)
-    strncpy (poConf->acDevice, "ada0", 64);
+    strncpy (poConf->acDevice, "ada0", 128);
     strncpy (poConf->acTitle, "ada0", 16);
 #elif defined(__sun__)
-    strncpy (poConf->acDevice, "sd0", 64);
+    strncpy (poConf->acDevice, "sd0", 128);
     strncpy (poConf->acTitle, "sd0", 16);
 #else
-    strncpy (poConf->acDevice, "/dev/sda", 64);
+    strncpy (poConf->acDevice, "/dev/sda", 128);
     status = stat (poConf->acDevice, &oStat);
     poConf->st_rdev = (status == -1 ? 0 : oStat.st_rdev);
     strncpy (poConf->acTitle, "sda", 16);
@@ -825,8 +826,8 @@ static void SetXferRate (Widget_t p_wTF, void *p_pvPlugin)
 
     /* Make it a multiple of 5 MB/s */
     poConf->iMaxXferMBperSec = 5 * round((double) atoi(pcXferRate) / 5);
-    if (poConf->iMaxXferMBperSec > 995)
-	poConf->iMaxXferMBperSec = 995;
+    if (poConf->iMaxXferMBperSec > INT16_MAX)
+	poConf->iMaxXferMBperSec = INT16_MAX - 2;
     else if (poConf->iMaxXferMBperSec < 5)
 	poConf->iMaxXferMBperSec = 5;
     DBG("XferRate rounded to %dMb/s\n", poConf->iMaxXferMBperSec);
@@ -984,6 +985,8 @@ static void diskperf_create_options (XfcePanelPlugin *plugin,
                                                 GTK_DIALOG_DESTROY_WITH_PARENT,
                                                 "gtk-close", GTK_RESPONSE_OK,
                                                 NULL);
+
+    gtk_window_set_resizable (GTK_WINDOW (dlg), FALSE);
     
     g_signal_connect (G_OBJECT (dlg), "response",
                       G_CALLBACK (diskperf_dialog_response), poPlugin);
@@ -991,8 +994,8 @@ static void diskperf_create_options (XfcePanelPlugin *plugin,
     gtk_window_set_position (GTK_WINDOW (dlg), GTK_WIN_POS_CENTER);
     gtk_window_set_icon_name (GTK_WINDOW (dlg), "drive-harddisk");
     
-    vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, BORDER);
-    gtk_container_set_border_width (GTK_CONTAINER (vbox), BORDER - 2);
+    vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 18);
+    gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
     gtk_widget_show(vbox);
     gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area(GTK_DIALOG (dlg))), vbox,
                         TRUE, TRUE, 0);
